char internal_keysbuf[]=
">LSF-keys\n"
"MoveUp :  Up;\n"
"MoveDown: Down;\n"
"MoveLeft: Left;\n"
"MoveRight: Right;\n"
"Execute: Return;Shift+Return;Ctrl+Return;\n"
"ManualSelectFile: Insert;\n"
"ManPage: F1;\n"
"UserMenu: F2;\n"
"ViewFile: F3;\n"
"EditFile: F4;\n"
"CopyFile: F5;\n"
"MoveFile: F6;\n"
"MakeDir: F7;\n"
"DelFile: F8;Delete;\n"
"AttributeFile: F9;\n"
"Quit: F10;\n"
"KillMenu: F11;\n"
"SwitchPanels: Tab;\n"
"SwitchToTerm: Escape;Ctrl+o;\n"
"RereadDir: Ctrl+r;\n"
"InvertMaskSelection: KP_Multiply;\n"
"AddMaskSelection: KP_Add;\n"
"DelMaskSelection: KP_Subtract;\n"
"FindFile: Ctrl+f;\n"
"QuickDir: Ctrl+q;\n"
"MemoryInfo: Ctrl+m;\n"
"Print: Ctrl+F9;\n"
"SimpleView: Shift+F3;\n"
"RemountList: Ctrl+F1;\n"
"RemountCurrent: Shift+F1;\n"
"NewFileEdit: Shift+F4;\n"
"DiskInfo: Ctrl+l;\n"
"CmdLineCommandUp: Shift+Up;Ctrl+e;\n"
"CmdLineCommandDown: Shift+Down;\n"
"CmdLineCommandLeft: Shift+Left;\n"
"CmdLineCommandRight: Shift+Right;\n"
"AddtoBookMark: Ctrl+a;\n"
"SwitchToBook1: Ctrl+1;\n"
"SwitchToBook2: Ctrl+2;\n"
"SwitchToBook3: Ctrl+3;\n"
"SwitchToBook4: Ctrl+4;\n"
"SwitchToBook5: Ctrl+5;\n"
"SwitchToBook6: Ctrl+6;\n"
"SwitchToBook7: Ctrl+7;\n"
"SwitchToBook8: Ctrl+8;\n"
"SwitchToBook9: Ctrl+9;\n"
"DelCurrentBook: Ctrl+Delete;\n"
"ChangeOwner: Shift+F9;\n"
"CleanAFScache: Ctrl+c;\n"
"ActivateFtpLink: Ctrl+h;\n"
"InsertLeftDir: Ctrl+bracketleft;\n"
"InsertRightDir: Ctrl+bracketright;\n"
"SelectFileMask: Shift+KP_Add;\n"
"DeselectFileMask: Shift+KP_Subtract;\n"
"MoveCursorHome: Home;\n"
"MoveCursorEnd: End;\n"
"MoveCursorPageDown: Next;\n"
"MoveCursorPageUp: Prior;\n"
"InodeInfo: Ctrl+i;\n"
"QuickFileInfo: KP_Insert;KP_0;\n"
">endLSF";
